ExponentialSchedule

Struct ExponentialSchedule 

pub struct ExponentialSchedule {
    initial: Duration,
    maximum: Duration,
    multiplier: u32,
    current: Duration,
}
Bounded exponential delay schedule.

Fields

initial: Durationmaximum: Durationmultiplier: u32current: Duration

Implementations

Source

impl ExponentialSchedule

pub fn new(initial: Duration, maximum: Duration, multiplier: u32) -> Self

Create a schedule whose first delay is initial and whose delays never exceed maximum.

pub fn next_delay(&mut self) -> Duration

Return the current delay and advance the schedule for the next attempt.

pub fn reset(&mut self)

Reset the next delay to the initial bounded value.

pub const fn current_delay(&self) -> Duration

Inspect the delay that will be returned by Self::next_delay.